This is a PDF harvester for Dokang (https://github.com/Polyconseil/dokang).

Build status: |travis-ci-status|_

.. |travis-ci-status| image:: https://travis-ci.org/Polyconseil/dokang_pdf.svg?branch=master

.. _travis-ci-status: https://travis-ci.org/Polyconseil/dokang_pdf


Usage
=====

from dokang_pdf import PdfHarvester


License
=======

Dokang is written by Polyconseil and is licensed under the 3-clause
BSD license, a copy of which is included in the source.
